<div style="text-align:center">
<img src="https://raw.githubusercontent.com/rpoteau/pyphyschemtools/main/pyphyschemtools/icons_logos_banner/tools4pyPC_banner.png" alt="t4pyPCbanner" width="800"/>
</div>

<br>

**pyphyschemtools** is a collection of Python utilities designed to facilitate data processing and analysis in the field of physical chemistry. This library is an integral part of the broader [**pyPhysChem project**](https://github.com/rpoteau/pyPhysChem/), aimed at providing open-source, reproducible tools for researchers and students.



---

**Installation**

Activate your python environment and run:

```bash
pip install pyphyschem